@@ -30,6 +30,18 @@
 #' \ifelse{html}{\out{F<sub>gut</sub>}}{\eqn{F_{gut}}}
 #' using \code{\link{calc_fgut.oral}}.
 #' 
+#' Because this model does not simulate exhalation, inhalation, and other 
+#' processes relevant to volatile chemicals, this model is by default 
+#' restricted to chemicals with a logHenry's Law Constant less than that of 
+#' Acetone, a known volatile chemical. That is, chemicals with logHLC > -4.5 
+#' (Log10 atm-m3/mole) are excluded. Volatility is not purely determined by the 
+#' Henry's Law Constant, therefore this chemical exclusion may be turned off 
+#' with the argument "physchem.exclude = FALSE". Similarly, per- and 
+#' polyfluoroalkyl substances (PFAS) are excluded by default because the 
+#' transporters that often drive PFAS toxicokinetics are not included in this 
+#' model. However, PFAS chemicals can be included with the argument 
+#' "class.exclude = FALSE".
+#' 
 #' @param chem.cas Chemical Abstract Services Registry Number (CAS-RN) -- the 
 #' chemical must be identified by either CAS, name, or DTXISD
 #' 
@@ -51,6 +63,10 @@
 #' @param class.exclude Exclude chemical classes identified as outside of 
 #' domain of applicability by relevant modelinfo_[MODEL] file (default TRUE).
 #' 
+#' @param physchem.exclude Exclude chemicals on the basis of physico-chemical
+#' properties (currently only Henry's law constant) as specified by 
+#' the relevant modelinfo_[MODEL] file (default TRUE).
+#' 
 #' @param force.human.clint.fup Uses human hepatic intrinsic clearance and fraction
 #' of unbound plasma in calculation of partition coefficients for rats if true.
 #' 
@@ -73,13 +89,17 @@
 #' equal to this value (default is 0.0001 -- half the lowest measured Fup in our
 #' dataset).
 #' 
-#' @param Caco2.options A list of options to use when working with Caco2 apical to
-#' basolateral data \code{Caco2.Pab}, default is Caco2.options = list(Caco2.Pab.default = 1.6,
-#' Caco2.Fabs = TRUE, Caco2.Fgut = TRUE, overwrite.invivo = FALSE, keepit100 = FALSE). Caco2.Pab.default sets the default value for 
-#' Caco2.Pab if Caco2.Pab is unavailable. Caco2.Fabs = TRUE uses Caco2.Pab to calculate
-#' fabs.oral, otherwise fabs.oral = \code{Fabs}. Caco2.Fgut = TRUE uses Caco2.Pab to calculate 
-#' fgut.oral, otherwise fgut.oral = \code{Fgut}. overwrite.invivo = TRUE overwrites Fabs and Fgut in vivo values from literature with 
-#' Caco2 derived values if available. keepit100 = TRUE overwrites Fabs and Fgut with 1 (i.e. 100 percent) regardless of other settings.
+#' @param Caco2.options A list of options to use when working with Caco2 apical 
+#' to basolateral data \code{Caco2.Pab}, default is Caco2.options = 
+#' list(Caco2.Pab.default = 1.6, Caco2.Fabs = TRUE, Caco2.Fgut = TRUE, 
+#' overwrite.invivo = FALSE, keepit100 = FALSE). Caco2.Pab.default sets the 
+#' default value for Caco2.Pab if Caco2.Pab is unavailable. Caco2.Fabs = TRUE 
+#' uses Caco2.Pab to calculate fabs.oral, otherwise fabs.oral = \code{Fabs}. 
+#' Caco2.Fgut = TRUE uses Caco2.Pab to calculate 
+#' fgut.oral, otherwise fgut.oral = \code{Fgut}. overwrite.invivo = TRUE 
+#' overwrites Fabs and Fgut in vivo values from literature with 
+#' Caco2 derived values if available. keepit100 = TRUE overwrites Fabs and Fgut 
+#' with 1 (i.e. 100 percent) regardless of other settings.
 #' See \code{\link{get_fbio}} for further details.
 #' 
 #' @param ... Other parameters
@@ -109,6 +129,14 @@
 #'
 #' \insertRef{kilford2008hepatocellular}{httk}
 #'
+#' \insertRef{wambaugh2025simple}{httk}
+#'
+#' \insertRef{rotroff2010incorporating}{httk}
+#'
+#' \insertRef{wetmore2012integration}{httk}
+#'
+#' \insertRef{wetmore2015incorporating}{httk}
+#'
 #' @seealso \code{\link{calc_analytic_css_3compss}}
 #'
 #' @seealso \code{\link{apply_clint_adjustment}}
@@ -119,8 +147,18 @@
 #'
 #' @examples
 #' 
-#'  parameters <- parameterize_steadystate(chem.name='Bisphenol-A',species='Rat')
-#'  parameters <- parameterize_steadystate(chem.cas='80-05-7')
+#'  parameters1 <- parameterize_steadystate(chem.name='Bisphenol-A',species='Rat')
+#' 
+#'  parameters2 <- parameterize_steadystate(chem.cas='80-05-7')
+#' 
+#' # The following will not work because Diquat dibromide monohydrate's 
+#' # Henry's Law Constant (-3.912) is higher than that of Acetone (~-4.5):
+#' try(parameters3 <- parameterize_steadystate(chem.cas = "6385-62-2"))
+#' 
+#' # However, we can turn off checking for phys-chem properties, since we know
+#' # that  Diquat dibromide monohydrate is not too volatile:
+#' parameters3 <- parameterize_steadystate(chem.cas = "6385-62-2",
+#'                                  physchem.exclude = FALSE) 
 #' 
 #' @keywords 3compss
 #' 
@@ -133,6 +171,7 @@ parameterize_steadystate <- function(
                               clint.pvalue.threshold=0.05,
                               default.to.human=FALSE,
                               class.exclude=TRUE,
+                              physchem.exclude=TRUE,
                               force.human.clint.fup=FALSE,
                               adjusted.Funbound.plasma=TRUE,
                               adjusted.Clint=TRUE,
@@ -175,6 +214,7 @@ parameterize_steadystate <- function(
               model="3compartmentss",
               species=species,
               class.exclude=class.exclude,
+              physchem.exclude=physchem.exclude,
               default.to.human=default.to.human|force.human.clint.fup)
 
   #Capitalize the first letter of species only:
@@ -357,6 +397,9 @@ parameterize_steadystate <- function(
       chem.cas=chem.cas,
       chem.name=chem.name,
       species=species,
+      parameterize.args.list = list(default.to.human=default.to.human,
+                               class.exclude=class.exclude,
+                               physchem.exclude=physchem.exclude),
       suppress.messages=suppress.messages
       ),
     Caco2.options))
