@@ -39,7 +39,7 @@
 #' flows) but default.to.human = TRUE must be used to substitute human
 #' fraction unbound, partition coefficients, and intrinsic hepatic clearance.
 #' (NOTE: The 'default.to.human' specification should be included as part of the
-#' arguments listed in 'parameterize.arg.list'.)
+#' arguments listed in 'parameterize.args.list'.)
 #'  
 #' For both plotting purposes and helping the numerical equation solver, it is
 #' helpful to specify that time points shortly before and after dosing are 
@@ -121,22 +121,12 @@
 #' @param recalc.clearance Recalculates the the hepatic clearance
 #' (Clmetabolism) with new million.cells.per.gliver parameter.
 #' 
-#' @param adjusted.Funbound.plasma Uses adjusted Funbound.plasma when set to
-#' TRUE along with partition coefficients calculated with this value.
-#' 
-#' @param restrictive.clearance Protein binding not taken into account (set to
-#' 1) in liver clearance if FALSE.
-#' 
 #' @param ... Additional arguments passed to the integrator.
 #' 
 #' @param monitor.vars Which variables are returned as a function of time. 
 #' Default values of NULL looks up variables specified in modelinfo_MODEL.R
 #' 
-#' @param minimum.Funbound.plasma Monte Carlo draws less than this value are set 
-#' equal to this value (default is 0.0001 -- half the lowest measured Fup in our
-#' dataset)
-#' 
-#' @param parameterize.arg.list Additional parameters passed to the model
+#' @param parameterize.args.list Additional parameters passed to the model
 #'   parameterization function (other than chemical identifier, `species`,
 #'   `suppress.messages`, `restrictive.clearance`, `adjusted.Funbound.plasma`,
 #'   and `minimum.Funbound.plasma`)
@@ -145,6 +135,11 @@
 #' side of an instantaneous event (like an iv injection). This helps ensure that
 #' abrupt changes plot well. Defaults to 1e-4.
 #' 
+#' @param forcings A way of passing time-dependent quantities to the ODE solver.
+#' Should take the form of a list of two-column matrices with the first column
+#' containing time values and the second column the value of quantity at those
+#' times. Default NULL.
+#' 
 #' @return A matrix of class deSolve with a column for time(in days), each
 #' compartment, the area under the curve, and plasma concentration and a row
 #' for each time point.
@@ -154,6 +149,7 @@
 #' 
 #' @references
 #' \insertRef{pearce2017httk}{httk}
+#' \insertRef{davidson2025enabling}{httk}
 #' 
 #' @keywords Solve
 #'
@@ -234,11 +230,9 @@ solve_model <- function(chem.name = NULL,
                     atol=1e-6,
                     recalc.blood2plasma=FALSE,
                     recalc.clearance=FALSE,
-                    restrictive.clearance=TRUE,
-                    adjusted.Funbound.plasma=TRUE,
-                    minimum.Funbound.plasma=0.0001,
-                    parameterize.arg.list=list(),
+                    parameterize.args.list =list(),
                     small.time = 1e-4, 
+                    forcings = NULL,
                     ...)
 {
 #R CMD CHECK throws notes about "no visible binding for global variable", for
@@ -415,39 +409,15 @@ specification in compartment_units for model ", model)
 # necessarily need all parameters associated with a given model to do this:)
   if (is.null(parameters))
   {
-    # restrictive.clearance can be set two places, so check for issues:
-    parameterize.restrictive.clearance <- restrictive.clearance
-    if ("restrictive.clearance" %in% names(parameterize.arg.list))
-    {
-      if (restrictive.clearance != 
-          parameterize.arg.list[["restrictive.clearance"]])
-      {
-        warning(paste("Value",
-                      parameterize.arg.list[["restrictive.clearance"]],
-                      "for restrictive.clearance in parameterze.arg.list",
-                      "has overwritting value",
-                      restrictive.clearance,
-                      "in arguments to solve.model."))
-        parameterize.restrictive.clearance <- 
-          parameterize.arg.list[["restrictive.clearance"]]
-       }
-       parameterize.arg.list <- parameterize.arg.list[!(
-                                   names(parameterize.arg.list) %in%
-                                   "restrictive.clearance")]
-    } 
-
     parameters <- do.call(parameterize_function, args=purrr::compact(c(
       list(
         chem.cas=chem.cas,
         chem.name=chem.name,
         dtxsid=dtxsid,
         species=species,
-        suppress.messages=suppress.messages,
-        adjusted.Funbound.plasma=adjusted.Funbound.plasma,
-        minimum.Funbound.plasma=minimum.Funbound.plasma,
-        restrictive.clearance=parameterize.restrictive.clearance
+        suppress.messages=suppress.messages
         ),
-      parameterize.arg.list))) 
+      parameterize.args.list))) 
   } else {
     if (!all(param_names %in% names(parameters)))
     {
@@ -486,14 +456,19 @@ specification in compartment_units for model ", model)
     {
       if (is.null(chem.name) & is.null(chem.cas)) 
         stop('Chemical name or CAS must be specified to recalculate hepatic clearance.')
-      ss.params <- parameterize_steadystate(chem.name=chem.name,chem.cas=chem.cas)
+      ss.params <- parameterize_steadystate(chem.name=chem.name,
+                                            chem.cas=chem.cas)
     }
     ss.params[[names(ss.params) %in% names(parameters)]] <- 
       parameters[[names(ss.params) %in% names(parameters)]]
-    parameters[['Clmetabolismc']] <- calc_hep_clearance(parameters=ss.params,
-      hepatic.model='unscaled',
-      restrictive.clearance = restrictive.clearance,
-      suppress.messages=TRUE)
+    parameters[['Clmetabolismc']] <- do.call(calc_hep_clearance, 
+                                             args=purrr::compact(c(
+                                               parameters=ss.params,
+                                               species = species,
+                                               hepatic.model='unscaled',
+                                               restrictive.clearance = 
+                                                 parameterize.args.list[["restrictive.clearance"]],
+                                               suppress.messages=TRUE)))
   }
     
   # If there is not an explicit liver we need to include a factor for first-
@@ -814,7 +789,7 @@ specification in compartment_units for model ", model)
   dosing.matrix <- dosing$dosing.matrix
   daily.dose <- dosing$daily.dose
   doses.per.day <- dosing$doses.per.day
-  forcings <- dosing$forcings
+  forcings <- rbind(forcings, dosing$forcings)
 
 # Add the first dose:
   if (!is.null(initial.dose))
@@ -864,11 +839,15 @@ specification in compartment_units for model ", model)
       time = round(dose.times,8),
       value = dose.vec, 
       method = rep(dose.type,num.doses))
-    #Update our times vector to include times of provided dosing events, as well as
-    #the times of dosing events incremented by small.time for visualization.
+    # Update our times vector to include times of provided dosing events, as 
+    # well as the times of dosing events incremented by small.time for 
+    # visualization.
     dose.times <- c(sapply(eventdata$time-small.time, function(x) max(x,0)),
       eventdata$time,
       eventdata$time+small.time)
+    # Only include dose.times after requested start time:
+    dose.times <- dose.times[dose.times >= start.time]
+    # Ensure times is sorted and unique:
     times <- sort(unique(c(times, dose.times)))
     # Also add the times of the doses to those returned by the function:
     requested.times <- sort(unique(c(requested.times, dose.times)))
