@@ -38,6 +38,7 @@ extern void derivs3comp2(int *, double *, double *, double *, double *, int *);
 extern void jac3comp2(int *, double *, double *, int *, int *, double *, int *, double *, int *);
 extern void event3comp2(int *, double *, double *);
 extern void root3comp2(int *, double *, double *, int *, double *, double *, int *);
+extern void initforc3comp2(void *);
 
 extern void getParms_gas_pbtk(double *, double *, int *);
 extern void initmod_gas_pbtk(void *);
@@ -52,8 +53,25 @@ extern void initmodfetal_pbtk(void *);
 extern void derivsfetal_pbtk(int *, double *, double *, double *, double *, int *);
 extern void jacfetal_pbtk(int *, double *, double *, int *, int *, double *, int *, double *, int *);
 extern void eventfetal_pbtk(int *, double *, double *);
-extern void rootfetal_pbtk(int *, double *, double *, int *, double *, double *, int *);
-extern void initfetal_pbtk(void *);
+extern void rootfetal_pbtk (int *, double *, double *, int *, double *, double *, int *);
+extern void initforcfetal_pbtk(void *);
+
+extern void getParms_firsttrimester(double *, double *, int *);
+extern void initmod_firsttrimester(void *);
+extern void derivs_firsttrimester(int *, double *, double *, double *, double *, int *);
+extern void jac_firsttrimester(int *, double *, double *, int *, int *, double *, int *, double *, int *);
+extern void event_firsttrimester(int *, double *, double *);
+extern void root_firsttrimester(int *, double *, double *, int *, double *, double *, int *);
+extern void initforc_firsttrimester(void *);
+
+extern void rootpbtk_lifestage(int *, double *, double *, int *, double *, double *, int *);
+extern void getParmspbtk_lifestage(double *, double *, int *);
+extern void initmodpbtk_lifestage(void *);
+extern void initforcpbtk_lifestage(void *);
+extern void derivspbtk_lifestage(int *, double *, double *, double *, double *, int *);
+extern void jacpbtk_lifestage(int *, double *, double *, int *, int *, double *, int *, double *, int *);
+extern void eventpbtk_lifestage(int *, double *, double *);
+extern void rootpbtk_lifestage(int *, double *, double *, int *, double *, double *, int *);
 
 static const R_CMethodDef CEntries[] = {
     {"getParmspbtk",       (DL_FUNC) &getParmspbtk,       3},
@@ -62,7 +80,7 @@ static const R_CMethodDef CEntries[] = {
     {"jacpbtk", (DL_FUNC) &jacpbtk, 9},
     {"eventpbtk",       (DL_FUNC) &eventpbtk,       3},
     {"rootpbtk",       (DL_FUNC) &rootpbtk,       7},
-//    {"initforcpbtk", (DL_FUNC) &initforcpbtk, 1},
+    {"initforcpbtk", (DL_FUNC) &initforcpbtk, 1},
 
     {"getParms1comp", (DL_FUNC) &getParms1comp, 3},
     {"initmod1comp", (DL_FUNC) &initmod1comp, 1},
@@ -70,7 +88,7 @@ static const R_CMethodDef CEntries[] = {
     {"jac1comp", (DL_FUNC) &jac1comp, 9},
     {"event1comp", (DL_FUNC) &event1comp, 3},
     {"root1comp", (DL_FUNC) &root1comp, 7},
-//    {"initforc1comp", (DL_FUNC) &initforc1comp, 1},
+    {"initforc1comp", (DL_FUNC) &initforc1comp, 1},
 
     {"getParms3comp", (DL_FUNC) &getParms3comp, 3},
     {"initmod3comp", (DL_FUNC) &initmod3comp, 1},
@@ -78,7 +96,7 @@ static const R_CMethodDef CEntries[] = {
     {"jac3comp", (DL_FUNC) &jac3comp, 9},
     {"event3comp", (DL_FUNC) &event3comp, 3},
     {"root3comp", (DL_FUNC) &root3comp, 7},
-//    {"initforc3comp", (DL_FUNC) &initforc3comp, 1},
+    {"initforc3comp", (DL_FUNC) &initforc3comp, 1},
 
     {"getParms3comp2", (DL_FUNC) &getParms3comp2, 3},
     {"initmod3comp2", (DL_FUNC) &initmod3comp2, 1},
@@ -86,7 +104,7 @@ static const R_CMethodDef CEntries[] = {
     {"jac3comp2", (DL_FUNC) &jac3comp2, 9},
     {"event3comp2", (DL_FUNC) &event3comp2, 3},
     {"root3comp2", (DL_FUNC) &root3comp2, 7},
-//    {"initforc3comp2", (DL_FUNC) &initforc3comp2, 1},
+    {"initforc3comp2", (DL_FUNC) &initforc3comp2, 1},
 
     {"getParms_gas_pbtk", (DL_FUNC) &getParms_gas_pbtk, 3},
     {"initmod_gas_pbtk", (DL_FUNC) &initmod_gas_pbtk, 1},
@@ -102,7 +120,22 @@ static const R_CMethodDef CEntries[] = {
     {"jacfetal_pbtk", (DL_FUNC) &jacfetal_pbtk, 9},
     {"eventfetal_pbtk", (DL_FUNC) &eventfetal_pbtk, 3},
     {"rootfetal_pbtk", (DL_FUNC) &rootfetal_pbtk, 7},
-//    {"initforcfetal_pbtk", (DL_FUNC) &initforcfetal_pbtk, 1},
+    {"initforcfetal_pbtk", (DL_FUNC) &initforcfetal_pbtk, 1},
+      
+    {"getParms_firsttrimester", (DL_FUNC) &getParms_firsttrimester, 3},
+    {"initmod_firsttrimester", (DL_FUNC) &initmod_firsttrimester, 1}, 	
+    {"derivs_firsttrimester", (DL_FUNC) &derivs_firsttrimester, 6},
+    {"jac_firsttrimester", (DL_FUNC) &jac_firsttrimester, 9},
+    {"event_firsttrimester", (DL_FUNC) &event_firsttrimester, 3},
+    {"root_firsttrimester", (DL_FUNC) &root_firsttrimester, 7},
+
+    {"getParmspbtk_lifestage", (DL_FUNC) &getParmspbtk_lifestage, 3},
+    {"initmodpbtk_lifestage", (DL_FUNC) &initmodpbtk_lifestage, 1},
+    {"initforcpbtk_lifestage", (DL_FUNC) &initforcpbtk_lifestage, 1},
+    {"derivspbtk_lifestage", (DL_FUNC) &derivspbtk_lifestage, 6},
+    {"jacpbtk_lifestage", (DL_FUNC) &jacpbtk_lifestage, 9},
+    {"eventpbtk_lifestage", (DL_FUNC) &eventpbtk_lifestage, 3},
+    {"rootpbtk_lifestage", (DL_FUNC) &rootpbtk_lifestage, 7},
 
     {NULL, NULL, 0}
 };
