@@ -13,7 +13,7 @@ calc_analytic_css(chem.cas="80-05-7",model="1compartment",tissue="brain")
 
 ##head(solve_1comp(chem.name="bisphenol a"))
 #head(solve_1comp(chem.cas="80-05-7"))
-head(solve_1comp(parameters=parameterize_1comp(chem.cas="80-05-7")))
+head(solve_1comp(parameters=parameterize_1comp(chem.cas="80-05-7"),days=1))
 
 calc_vdist(chem.name="triclosan")
 calc_vdist(chem.cas="80-05-7")
@@ -25,6 +25,8 @@ calc_vdist(parameters=params)
 params <- parameterize_pbtk(chem.name="triclosan")
 calc_vdist(parameters=params)
 
-parameterize_1comp(chem.name="Aminopterin")
+p <- parameterize_1comp(chem.name="Aminopterin")[sort(names(parameterize_1comp(chem.name="Aminopterin")))]
+# Try to standardize order of variable names
+for (this.param in names(p)[order(toupper(names(p)))]) cat(paste(this.param,": ",p[[this.param]],"\r\n",sep=""))
 
 quit("no")
\ No newline at end of file
