@@ -10,4 +10,8 @@ head(solve_fetal_pbtk(chem.name = 'bisphenol a', daily.dose = 1,
 head(solve_fetal_pbtk(chem.cas="80-05-7"))
 head(solve_fetal_pbtk(parameters=parameterize_fetal_pbtk(chem.cas="80-05-7")))
 
+p <- parameterize_fetal_pbtk(chem.name='bisphenol a')[sort(names(parameterize_fetal_pbtk(chem.name='bisphenol a')))]
+# Try to standardize order of variable names
+for (this.param in names(p)[order(toupper(names(p)))]) cat(paste(this.param,": ",p[[this.param]],"\r\n",sep=""))
+
 quit("no")
\ No newline at end of file
