@@ -6,16 +6,16 @@ rm(list=ls())
 library(httk)
 
 # The following arguments were added: method = "lsode",mf = 10.
-# Rationale: Following is required for the same results on various OS's due to
-#   precision differences.
-head(solve_gas_pbtk(chem.name="pyrene",times=c(0,0.1,0.05),
-                    method = "lsode",mf = 10))
-head(solve_gas_pbtk(chem.cas="129-00-0",times=c(0,0.1,0.05),
-                    method = "lsode",mf = 10))
-head(solve_gas_pbtk(
+# Rationale: Use of signif is required for the same results on various OS's due
+#   to precision differences.
+signif(head(solve_gas_pbtk(chem.name="pyrene",times=c(0,0.1,0.05),
+                    method = "lsode",mf = 10)),2)
+signif(head(solve_gas_pbtk(chem.cas="129-00-0",times=c(0,0.1,0.05),
+                    method = "lsode",mf = 10)),2)
+signif(head(solve_gas_pbtk(
   parameters=parameterize_gas_pbtk(chem.cas="129-00-0"),
   times=c(0,0.1,0.05),
-  method = "lsode",mf = 10))
+  method = "lsode",mf = 10)),2)
 
 p <- parameterize_gas_pbtk(chem.name="styrene")[sort(names(parameterize_gas_pbtk(chem.name="styrene")))]
 # Try to standardize order of variable names
